[Xulu-commits] r72 - branches/1.8-gt2-2.6/src/edu/bonn/xulu/plugin/vis
scm-commit@wald.intevation.org
scm-commit at wald.intevation.org
Thu Jan 28 14:48:38 CET 2010
Author: mojays
Date: 2010-01-28 14:48:38 +0100 (Thu, 28 Jan 2010)
New Revision: 72
Modified:
branches/1.8-gt2-2.6/src/edu/bonn/xulu/plugin/vis/GTEditorTool.java
Log:
JEditorPane renamed to JMapEditorPane
JEditorToolBar renamed to JMapEditorToolBar
Modified: branches/1.8-gt2-2.6/src/edu/bonn/xulu/plugin/vis/GTEditorTool.java
===================================================================
--- branches/1.8-gt2-2.6/src/edu/bonn/xulu/plugin/vis/GTEditorTool.java 2010-01-28 11:59:06 UTC (rev 71)
+++ branches/1.8-gt2-2.6/src/edu/bonn/xulu/plugin/vis/GTEditorTool.java 2010-01-28 13:48:38 UTC (rev 72)
@@ -17,7 +17,7 @@
import schmitzm.data.property.ValueProperty;
import schmitzm.geotools.gui.GeoMapPane;
-import schmitzm.geotools.gui.JEditorPane;
+import schmitzm.geotools.gui.JMapEditorPane;
import schmitzm.geotools.gui.LayeredEditorFrame;
import schmitzm.geotools.gui.LayeredMapPane;
import schmitzm.geotools.map.event.JMapPaneListener;
@@ -49,7 +49,7 @@
super( new LayeredEditorFrame(
new LayeredMapPane(
new GeoMapPane(
- new JEditorPane(),
+ new JMapEditorPane(),
null,
null,
null
@@ -59,7 +59,7 @@
XuluConstants.XULU_VIS_RES.getString("GTEditorTool.FrameTitle")
);
// set listener to recognize new layers
- ((JEditorPane)this.layeredMapPane.getMapPane()).addMapPaneListener(this);
+ ((JMapEditorPane)this.layeredMapPane.getMapPane()).addMapPaneListener(this);
}
/**
@@ -73,20 +73,20 @@
}
/**
* Lauscht auf das {@link JEditorPane}, um nach Beendigung eines Layers,
* dieses in den Xulu-Datenpool einzufuegen.
*/
public void performMapPaneEvent(MapPaneEvent e) {
try {
if ( e instanceof LayerEditFinishedEvent ) {
LayerEditFinishedEvent lefe = (LayerEditFinishedEvent)e;
- JEditorPane editor = (JEditorPane)lefe.getSource();
- JEditorPane.EditorMode mode = editor.getEditorMode();
+ JMapEditorPane editor = (JMapEditorPane)lefe.getSource();
+ JMapEditorPane.EditorMode mode = editor.getEditorMode();
// neues Objekt im Xulu-Datenpool nur, wenn komplett neues Layer
// erstellt wurde
- if ( JEditorPane.EditorMode.New_Point.equals(mode) ||
- JEditorPane.EditorMode.New_Line.equals(mode) ||
- JEditorPane.EditorMode.New_Polygon.equals(mode) )
+ if ( JMapEditorPane.EditorMode.New_Point.equals(mode) ||
+ JMapEditorPane.EditorMode.New_Line.equals(mode) ||
+ JMapEditorPane.EditorMode.New_Polygon.equals(mode) )
createNewXuluObjectInDatapool(editor);
}
} catch (Exception err) {
@@ -100,7 +100,7 @@
* @param name Bezeichnung fuer das neue Objekt im Datenpool
* @param fc neue {@link FeatureCollection}
*/
- protected void createNewXuluObjectInDatapool(JEditorPane editor) throws Exception {
+ protected void createNewXuluObjectInDatapool(JMapEditorPane editor) throws Exception {
FeatureCollection fc = editor.getEditorFeatureCollection();
MapLayer layer = editor.getEditorLayer();
String title = layer.getTitle();
@@ -73,20 +73,20 @@
}
/**
- * Lauscht auf das {@link JEditorPane}, um nach Beendigung eines Layers,
+ * Lauscht auf das {@link JMapEditorPane}, um nach Beendigung eines Layers,
* dieses in den Xulu-Datenpool einzufuegen.
*/
More information about the Xulu-commits
mailing list